==> jc-1.4.0.tar.gz: java/awt/PrintJob.h <==
// public abstract class java.awt.PrintJob

// class file dependencies
// @dep_class baa7d13f93470290 java_awt_PrintJob
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_PrintJob_H_
#define _JC_java_awt_PrintJob_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_PrintJob$sub_refs	_jc_java_awt_PrintJob$sub_refs;
typedef struct _jc_java_awt_PrintJob$sub_nonrefs	_jc_java_awt_PrintJob$sub_nonrefs;
typedef struct _jc_java_awt_PrintJob$refs	_jc_java_awt_PrintJob$refs;
typedef struct _jc_java_awt_PrintJob$nonrefs	_jc_java_awt_PrintJob$nonrefs;
typedef struct _jc_java_awt_PrintJob$object	_jc_java_awt_PrintJob$object;

typedef const struct _jc_java_awt_PrintJob$vmethods	_jc_java_awt_PrintJob$vmethods;
typedef const struct _jc_java_awt_PrintJob$vtable	_jc_java_awt_PrintJob$vtable;
typedef const struct _jc_java_awt_PrintJob$vtype	_jc_java_awt_PrintJob$vtype;

// Constructors
extern void _jc_java_awt_PrintJob$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_PrintJob$object *);

// Virtual methods
extern void _jc_java_awt_PrintJob$method$end$d5ec7c830865cdfd(_jc_env *, struct _jc_java_awt_PrintJob$object *);
extern void _jc_java_awt_PrintJob$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_java_awt_PrintJob$object *);
extern struct _jc_java_awt_Graphics$object *_jc_java_awt_PrintJob$method$getGraphics$77f02e8821861132(_jc_env *, struct _jc_java_awt_PrintJob$object *);
extern struct _jc_java_awt_Dimension$object *_jc_java_awt_PrintJob$method$getPageDimension$25cb109d89a313f1(_jc_env *, struct _jc_java_awt_PrintJob$object *);
extern jint _jc_java_awt_PrintJob$method$getPageResolution$e7ca7dd373614a51(_jc_env *, struct _jc_java_awt_PrintJob$object *);
extern jboolean _jc_java_awt_PrintJob$method$lastPageFirst$c1ae9ba7658dfb75(_jc_env *, struct _jc_java_awt_PrintJob$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_PrintJob$method_info$end$d5ec7c830865cdfd;
extern _jc_method _jc_java_awt_PrintJob$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_java_awt_PrintJob$method_info$getGraphics$77f02e8821861132;
extern _jc_method _jc_java_awt_PrintJob$method_info$getPageDimension$25cb109d89a313f1;
extern _jc_method _jc_java_awt_PrintJob$method_info$getPageResolution$e7ca7dd373614a51;
extern _jc_method _jc_java_awt_PrintJob$method_info$lastPageFirst$c1ae9ba7658dfb75;

// Virtual methods structure
struct _jc_java_awt_PrintJob$vmethods {
	void	(*end$d5ec7c830865cdfd)(_jc_env *, struct _jc_java_awt_PrintJob$object *);
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_java_awt_PrintJob$object *);
	struct _jc_java_awt_Graphics$object	*(*getGraphics$77f02e8821861132)(_jc_env *, struct _jc_java_awt_PrintJob$object *);
	struct _jc_java_awt_Dimension$object	*(*getPageDimension$25cb109d89a313f1)(_jc_env *, struct _jc_java_awt_PrintJob$object *);
	jint	(*getPageResolution$e7ca7dd373614a51)(_jc_env *, struct _jc_java_awt_PrintJob$object *);
	jboolean	(*lastPageFirst$c1ae9ba7658dfb75)(_jc_env *, struct _jc_java_awt_PrintJob$object *);
};

// Vtable
struct _jc_java_awt_PrintJob$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_PrintJob$vmethods	java_awt_PrintJob;
};

// Vtype
struct _jc_java_awt_PrintJob$vtype {
	_jc_type			type;
	_jc_java_awt_PrintJob$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PrintJob$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PrintJob$refs {
    _jc_java_awt_PrintJob$sub_refs	java_awt_PrintJob;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PrintJob$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PrintJob$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_PrintJob$sub_nonrefs	java_awt_PrintJob;
};

// Object instance structure
struct _jc_java_awt_PrintJob$object {
	_jc_java_awt_PrintJob$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PrintJob$vtype	*vtype;
	_jc_java_awt_PrintJob$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PrintJob$vtype _jc_java_awt_PrintJob$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PrintJob, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PrintJob$class_object;

#endif	/* _JC_java_awt_PrintJob_H_ */

==> jc-1.4.5.tar.gz: java/awt/PrintJob.h <==
// public abstract class java.awt.PrintJob

// class file dependencies
// @dep_class baa7d13f93470290 java_awt_PrintJob
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_PrintJob_H_
#define _JC_java_awt_PrintJob_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_PrintJob$sub_refs	_jc_java_awt_PrintJob$sub_refs;
typedef struct _jc_java_awt_PrintJob$sub_nonrefs	_jc_java_awt_PrintJob$sub_nonrefs;
typedef struct _jc_java_awt_PrintJob$refs	_jc_java_awt_PrintJob$refs;
typedef struct _jc_java_awt_PrintJob$nonrefs	_jc_java_awt_PrintJob$nonrefs;
typedef struct _jc_java_awt_PrintJob$object	_jc_java_awt_PrintJob$object;

typedef const struct _jc_java_awt_PrintJob$vmethods	_jc_java_awt_PrintJob$vmethods;
typedef const struct _jc_java_awt_PrintJob$vtable	_jc_java_awt_PrintJob$vtable;
typedef const struct _jc_java_awt_PrintJob$vtype	_jc_java_awt_PrintJob$vtype;

// Constructors
extern void _jc_java_awt_PrintJob$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_PrintJob$method$end$d5ec7c830865cdfd(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_PrintJob$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Graphics$object *_jc_java_awt_PrintJob$method$getGraphics$77f02e8821861132(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_java_awt_PrintJob$method$getPageDimension$25cb109d89a313f1(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_PrintJob$method$getPageResolution$e7ca7dd373614a51(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_PrintJob$method$lastPageFirst$c1ae9ba7658dfb75(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_PrintJob$method_info$end$d5ec7c830865cdfd;
extern _jc_method _jc_java_awt_PrintJob$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_java_awt_PrintJob$method_info$getGraphics$77f02e8821861132;
extern _jc_method _jc_java_awt_PrintJob$method_info$getPageDimension$25cb109d89a313f1;
extern _jc_method _jc_java_awt_PrintJob$method_info$getPageResolution$e7ca7dd373614a51;
extern _jc_method _jc_java_awt_PrintJob$method_info$lastPageFirst$c1ae9ba7658dfb75;

// Virtual methods structure
struct _jc_java_awt_PrintJob$vmethods {
	void	(*end$d5ec7c830865cdfd)(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Graphics$object	*(*getGraphics$77f02e8821861132)(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getPageDimension$25cb109d89a313f1)(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;
	jint	(*getPageResolution$e7ca7dd373614a51)(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;
	jboolean	(*lastPageFirst$c1ae9ba7658dfb75)(_jc_env *, struct _jc_java_awt_PrintJob$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_PrintJob$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_PrintJob$vmethods	java_awt_PrintJob;
};

// Vtype
struct _jc_java_awt_PrintJob$vtype {
	_jc_type			type;
	_jc_java_awt_PrintJob$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PrintJob$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PrintJob$refs {
    _jc_java_awt_PrintJob$sub_refs	java_awt_PrintJob;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PrintJob$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PrintJob$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_PrintJob$sub_nonrefs	java_awt_PrintJob;
};

// Object instance structure
struct _jc_java_awt_PrintJob$object {
	_jc_java_awt_PrintJob$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PrintJob$vtype	*vtype;
	_jc_java_awt_PrintJob$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PrintJob$vtype _jc_java_awt_PrintJob$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PrintJob, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PrintJob$class_object;

#endif	/* _JC_java_awt_PrintJob_H_ */
